// Header definitions file for mcrtime.dll
//
// Latest revision date:  06-JUNE-2003
//
// This header file formally defines the type definitions used by\
// Masterclock, Inc.'s API for the MCRPC
// Master Clock Reference card.  The MCRPC is available in four distinct
// configurations:
//
//   MCRPC-ISA  ISA bus card, with or without integral GPS module
//   MCRPC-PCI  PCI bus card, with or without integral GPS module
//
// The primary function of the MCRPC is to provide a stable computer time
// reference.  In the absence of an integral GPS reference, the MCRPC can
// be set to an externally specified UTC time and date.  All other MCRPC
// functions are read-only.
//
// Copyright  2002-3 Masterclock, Inc.
//
#ifndef _MCRDEFS_H_
#define _MCRDEFS_H_

#define MCRTIME_API_LONG LONG

//////////////////////////////////////////////////////////////////////////////
//
// DLL-specific data types
//
//////////////////////////////////////////////////////////////////////////////

#pragma pack(push, 4)

typedef enum {RT_NONE, RT_GPS, RT_OBC} MCT_TIME_REF;

typedef enum {FT_NONE, FT_2D, FT_3D} MCT_FIX_TYPE;

typedef enum {FQ_NONE, FQ_NONDIFF, FQ_DIFF, FQ_ESTIMATED} MCT_FIX_QUALITY;

typedef struct
{
    int             major;              // Up to four version fields...
    int             minor;              // ...typically shown like "1.2.3.4"
    int             revision;
    int             build;
} MCT_VERSION;

typedef struct
{
    int             value;              // Firmware ROM checksum
} MCT_CHECKSUM;

typedef struct
{
    bool            hasGPS;             // true if GPS module present
    bool            hasOBC;             // true if local clock present
    MCT_TIME_REF    activeReference;    // currently active time source
    MCT_FIX_TYPE    gpsFixType;         // GPS receiver fix type
    MCT_FIX_QUALITY gpsFixQuality;      // GPS receiver fix quality
    int             gpsStatusFlags;     // GPS module health (normally 0xFF)
    int             gpsTemperature;     // GPS module temperature (Celsius)
    int             heartBeat;          // Toggles between 1/0 each 1 sec IRQ
} MCT_HW_STATUS;

typedef struct
{
    int             satsInView;         // Number of satellites in view
    int             satsInUse;          // Number of satellites in use
    int             PRN[12];            // Up to 12 satellite PRN IDs (< 100)
    int             SNR[12];            // Received SNR per satellite (dBs)
} MCT_SIGNAL_QUALITY;

typedef struct
{
    int             latDegrees;         // Latitude whole degrees
    double          latMinutes;         // Latitude minutes
    int             latPolarity;        // 'N', 'S', or '?'
    //
    int             lgtDegrees;         // Longitude whole degrees
    double          lgtMinutes;         // Longitude minutes
    int             lgtPolarity;        // 'E', 'W', or '?'
    //
    double          altitude;           // Altitude in meters
    double          speed;              // Speed in knots
    double          course;             // Course in degrees
} MCT_POSITION;

typedef struct
{
    int             year;               // Year (2000-2099)
    int             month;              // Month (1-12)
    int             day;                // Day (1-31)
    int             hour;               // UTC hour (0-23)
    int             minute;             // UTC minute (0-59)
    int             seconds;            // UTC second (0-59)
    int             millisec;           // UTC milliseconds
} MCT_SETTABLE_TIME;

typedef struct
{
    int             year;               // Year (1980-2099)
    int             month;              // Month (1-12)
    int             day;                // Day (1-31)
    int             hour;               // UTC hour (0-23)
    int             minute;             // UTC minute (0-59)
    int             seconds;            // UTC second (0-60)
    int             millisec;           // UTC milliseconds
    int             leapsecs;           // leap seconds (info only)
    LARGE_INTEGER   perfcount;          // Performance count at turn-of-second 
} MCT_TIME;

#pragma pack(pop)

#endif /* MCR_DEFS_H */